@@ -1,19 +1,19 @@
-use std::{cell::RefCell, collections::BTreeMap, rc::Rc, time::Duration, time::Instant};
+use std::{cell::RefCell, collections::BTreeMap, rc::Rc, time::Instant};
 
 use crate::framed::State;
-use crate::rt::time::sleep;
+use crate::time::{now, sleep, Millis};
 use crate::util::HashSet;
 
 pub struct Timer(Rc<RefCell<Inner>>);
 
 struct Inner {
-    resolution: Duration,
+    resolution: Millis,
     current: Option<Instant>,
     notifications: BTreeMap<Instant, HashSet<State>>,
 }
 
 impl Inner {
-    fn new(resolution: Duration) -> Self {
+    fn new(resolution: Millis) -> Self {
         Inner {
             resolution,
             current: None,
@@ -39,12 +39,13 @@ impl Clone for Timer {
 
 impl Default for Timer {
     fn default() -> Self {
-        Timer::with(Duration::from_secs(1))
+        Timer::new(Millis::ONE_SEC)
     }
 }
 
 impl Timer {
-    pub fn with(resolution: Duration) -> Timer {
+    /// Create new timer with resolution in milliseconds
+    pub fn new(resolution: Millis) -> Timer {
         Timer(Rc::new(RefCell::new(Inner::new(resolution))))
     }
 
@@ -74,11 +75,11 @@ impl Timer {
         if let Some(cur) = cur {
             cur
         } else {
-            let now = Instant::now();
+            let now_val = now();
             let inner = self.0.clone();
             let interval = {
                 let mut b = inner.borrow_mut();
-                b.current = Some(now);
+                b.current = Some(now_val);
                 b.resolution
             };
 
@@ -86,7 +87,7 @@ impl Timer {
                 sleep(interval).await;
                 let empty = {
                     let mut i = inner.borrow_mut();
-                    let now = i.current.take().unwrap_or_else(Instant::now);
+                    let now = i.current.take().unwrap_or_else(now);
 
                     // notify io dispatcher
                     while let Some(key) = i.notifications.keys().next() {
@@ -108,7 +109,7 @@ impl Timer {
                 }
             });
 
-            now
+            now_val
         }
     }
 }
